`juliet` is being developed by `Nestor Espinoza (@nespinoza)
<https://github.com/nespinoza>`_.

Major contributors to the project have been `Diana Kossakowski (@dianadianadiana; initial development of the project)
<https://github.com/dianadianadiana>`_, `Johannes Buchner (@JohannesBuchner; implementation of UltraNest) <https://github.com/JohannesBuchner>`_, `Jonas Kemmer (@JonasKemmer; implementation of additional Gaussian Process kernels) <https://github.com/JonasKemmer>`_, `Jayshil Patel (@Jayshil; implementation of secondary eclipses) <https://github.com/Jayshil>`_ and `Rachel Cooper (@rcooper295; implementation of the zeus sampler) <https://github.com/rcooper295>`_. 

Contributions have also been made by `Martin Schlecker (@matiscke) <https://github.com/matiscke>`_, `Jose Vines (@jvines) <https://github.com/jvines>`_, `Rene Tronsgaard (@tronsgaard) <https://github.com/tronsgaard>`_, `Ian Weaver (@icweaver) <https://github.com/icweaver>`_ and `Ricky O'Steen (@rosteen) <https://github.com/rosteen>`_.

Want to contribute? Grab a `project <https://github.com/nespinoza/juliet/issues>`_, create your own and open a `pull request <https://github.com/nespinoza/juliet/pulls>`_!
